
#include <windows.h>  
#include "helptest.h"  


#if defined (WIN32)
	#define IS_WIN32 TRUE
#else
	#define IS_WIN32 FALSE
#endif

#define IS_NT      IS_WIN32 && (BOOL)(GetVersion() < 0x80000000)
#define IS_WIN32S  IS_WIN32 && (BOOL)(!(IS_NT) && (LOBYTE(LOWORD(GetVersion()))<4))
#define IS_WIN95   (BOOL)(!(IS_NT) && !(IS_WIN32S)) && IS_WIN32

HINSTANCE hInst;   // current instance

LPCTSTR lpszAppName  = "MyApp";
LPCTSTR lpszTitle    = "Help Test Application"; 

BOOL RegisterWin95( CONST WNDCLASS* lpwc );

int APIENTRY WinMain( HINSTANCE hInstance, HINSTANCE hPrevInstance,
                      LPTSTR lpCmdLine, int nCmdShow)
{
   MSG      msg;
   HWND     hWnd; 
   WNDCLASS wc;

   // Register the main application window class.
   //............................................
   wc.style         = CS_HREDRAW | CS_VREDRAW;
   wc.lpfnWndProc   = (WNDPROC)WndProc;       
   wc.cbClsExtra    = 0;                      
   wc.cbWndExtra    = 0;                      
   wc.hInstance     = hInstance;              
   wc.hIcon         = LoadIcon( hInstance, lpszAppName ); 
   wc.hCursor       = LoadCursor(NULL, IDC_ARROW);
   wc.hbrBackground = (HBRUSH)(COLOR_APPWORKSPACE+1);
   wc.lpszMenuName  = lpszAppName;              
   wc.lpszClassName = lpszAppName;              

   if ( IS_WIN95 )
   {
      if ( !RegisterWin95( &wc ) )
         return( FALSE );
   }
   else if ( !RegisterClass( &wc ) )
      return( FALSE );

   hInst = hInstance; 

   // Create the main application window.
   //....................................
   hWnd = CreateWindow( lpszAppName, 
                        lpszTitle,    
                        WS_OVERLAPPEDWINDOW, 
                        CW_USEDEFAULT, 0, 
                        CW_USEDEFAULT, 0,  
                        NULL,              
                        NULL,              
                        hInstance,         
                        NULL               
                      );

   if ( !hWnd ) 
      return( FALSE );

   ShowWindow( hWnd, nCmdShow ); 
   UpdateWindow( hWnd );         

   while( GetMessage( &msg, NULL, 0, 0) )   
   {
      TranslateMessage( &msg ); 
      DispatchMessage( &msg );  
   }

   return( msg.wParam ); 
}


BOOL RegisterWin95( CONST WNDCLASS* lpwc )
{
   WNDCLASSEX wcex;

   wcex.style         = lpwc->style;
   wcex.lpfnWndProc   = lpwc->lpfnWndProc;
   wcex.cbClsExtra    = lpwc->cbClsExtra;
   wcex.cbWndExtra    = lpwc->cbWndExtra;
   wcex.hInstance     = lpwc->hInstance;
   wcex.hIcon         = lpwc->hIcon;
   wcex.hCursor       = lpwc->hCursor;
   wcex.hbrBackground = lpwc->hbrBackground;
   wcex.lpszMenuName  = lpwc->lpszMenuName;
   wcex.lpszClassName = lpwc->lpszClassName;

   // Added elements for Windows 95.
   //...............................
   wcex.cbSize = sizeof(WNDCLASSEX);
   wcex.hIconSm = LoadImage(wcex.hInstance, lpwc->lpszClassName, 
                            IMAGE_ICON, 16, 16,
                            LR_LOADREALSIZE );
			
   return RegisterClassEx( &wcex );
}

LRESULT CALLBACK WndProc( HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam )
{
   switch( uMsg )
   {
      case WM_COMMAND :
              switch( LOWORD( wParam ) )
              {
                 case IDM_HELP_TOPICS :
                        WinHelp( hWnd, "HELPTEST.HLP", HELP_FINDER, 0 );
                        break;
                
                 case IDM_TEST :
                        DialogBox( hInst, "HLPDialog", hWnd, (DLGPROC)HlpDialog );
                        break;

                 case IDM_ABOUT :
                        DialogBox( hInst, "AboutBox", hWnd, (DLGPROC)About );
                        break;

                 case IDM_EXIT :
                        DestroyWindow( hWnd );
                        break;
              }
              break;
      
      case WM_DESTROY :
              // Close Help file if it is displayed.
              //....................................
              WinHelp( hWnd, "HELPTEST.HLP",  HELP_QUIT, 0 );

              PostQuitMessage(0);
              break;

      default :
            return( DefWindowProc( hWnd, uMsg, wParam, lParam ) );
   }

   return( 0L );
}



LRESULT CALLBACK HlpDialog( HWND hDlg,           
                            UINT message,        
                            WPARAM wParam,       
                            LPARAM lParam)
{
static DWORD nIDs[] = { IDC_RADIO1, HELP_BASE+IDC_RADIO1,
                        IDC_RADIO2, HELP_BASE+IDC_RADIO2,
                        IDC_RADIO3, HELP_BASE+IDC_RADIO3,
                        IDOK,       HELP_BASE+IDOK,
                        IDCANCEL,   HELP_BASE+IDCANCEL,
                        IDHELP,     HELP_BASE+IDHELP,
                        0, 0 };

   switch (message) 
   {
       case WM_INITDIALOG : 
               SetWindowLong( hDlg, GWL_EXSTYLE, 
                              GetWindowLong( hDlg, GWL_EXSTYLE ) | WS_EX_CONTEXTHELP );

               return (TRUE);

       case WM_HELP :
               {
                  int i = 0;
                  LPHELPINFO lpInfo = (LPHELPINFO)lParam;

                  // Make sure that the window is within our help IDs.
                  // This elliminates the "No help..." message.
                  //..................................................
                  while( nIDs[i] )
                  {
                     if ( nIDs[i] == (DWORD)GetWindowLong( lpInfo->hItemHandle, GWL_ID ) )
                     {
                        WinHelp( lpInfo->hItemHandle, "HELPTEST.HLP", HELP_WM_HELP, (DWORD)(LPVOID)nIDs );
                        break;
                     }
                     i+=2;
                  }
               }
               break;

       case WM_CONTEXTMENU :
               {
                  int i = 0;

                  // Make sure that the window is within our help IDs.
                  // This elliminates the "No help..." message.
                  //..................................................
                  while( nIDs[i] )
                  {
                     if ( nIDs[i] == (DWORD)GetWindowLong( (HWND)wParam, GWL_ID ) )
                     {
                        WinHelp( (HWND)wParam, "HELPTEST.HLP", HELP_CONTEXTMENU, (DWORD)(LPVOID)nIDs );
                        break;
                     }
                     i+=2;
                  }
               }
               break;

       case WM_TCARD :
               switch( wParam )
               {
                  case IDOK : 
                         EndDialog( hDlg, IDOK );
                         break;

                  case IDCANCEL :
                         EndDialog( hDlg, IDCANCEL );
                         break;

                  case IDABORT :
                         EnableWindow( hDlg, TRUE );
                         break;

                  case HELP_TCARD_DATA :
                         CheckRadioButton( hDlg, IDC_RADIO1, IDC_RADIO3, lParam );
                         break;
               }
               break;

       case WM_COMMAND:                              
               switch( LOWORD( wParam ) )
               {
                  case IDOK :
                         EndDialog( hDlg, IDOK );
                         break;

                  case IDCANCEL :
                         EndDialog( hDlg, IDCANCEL );
                         break;

                  case IDHELP :
                         WinHelp( hDlg, "HELPTEST.HLP", HELP_TCARD | HELP_CONTEXT, IDH_TRAINING );
                         EnableWindow( hDlg, FALSE );
                         break;
               }
               break;
   }

   return (FALSE); 
}


LRESULT CALLBACK About( HWND hDlg,           
                        UINT message,        
                        WPARAM wParam,       
                        LPARAM lParam)
{
   switch (message) 
   {
       case WM_INITDIALOG: 
               return (TRUE);

       case WM_COMMAND:                              
               if (   LOWORD(wParam) == IDOK         
                   || LOWORD(wParam) == IDCANCEL)    
               {
                       EndDialog(hDlg, TRUE);        
                       return (TRUE);
               }
               break;
   }

   return (FALSE); 
}
